package cn.estsh.i3plus.pojo.base.bean;

import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import org.hibernate.annotations.GenericGenerator;
import springfox.documentation.annotations.ApiIgnore;

import javax.persistence.*;
import javax.xml.bind.annotation.XmlType;
import java.io.Serializable;

/**
 * @Description :
 * @Reference :
 * @Author : alwaysfrin
 * @CreateDate : 2018-09-04 15:58
 * @Modify:
 **/
@Data
@Entity
//以子类table为准
@javax.persistence.Inheritance(strategy=InheritanceType.TABLE_PER_CLASS)
@JsonInclude(value = JsonInclude.Include.NON_EMPTY) //""或null属性不参加序列转换
public abstract class BaseBean implements Serializable {

    private static final long serialVersionUID = 1L;

    //此处使用hibernate的主键策略方式
    //手动设置,使用iplus-platform-common中的idtool生成
    //将Long类型系列化成String避免精度丢失
    @Id
    @GeneratedValue(generator = "IDGenerator")
    @GenericGenerator(name = "IDGenerator", strategy = "assigned")
    @Column(name="id")
    @ApiParam(value = "主键",example = "0")
    @JsonSerialize(using = ToStringSerializer.class)
    public Long id;

    //get单独处理
    public Long getId() {
        if(id != null) {
            return id.longValue();
        }else{
            return id;
        }
    }

    @Column(name="ORGANIZE_CODE")
    @ApiParam(value ="组织代码")
    private String organizeCode;

    @Column(name="is_valid")
    @ApiParam(value = "有效性",example = "1")
    //启用停用
    public Integer isValid;    //CommonEnumUtil.IS_VAILD;

    @Column(name="is_deleted")
    @ApiParam(value = "是否已删除",example = "2")
    //逻辑删除，软删除
    public Integer isDeleted;    //CommonEnumUtil.TRUE_OR_FALSE

    @Column(name="create_user",updatable = false)
    @ApiParam(value = "创建用户")
    public String createUser;

    @Column(name="create_date",updatable = false)
    @ApiParam(value = "创建日期")
    public String createDatetime;

    @Column(name="modify_user")
    @ApiParam(value = "修改人")
    public String modifyUser;

    @Column(name="modify_date")
    @ApiParam(value = "修改日期")
    public String modifyDatetime;

    @Transient
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @ApiParam(value="创建日期查询用，查询起始日期",example = "2018-01-01 01:00:00")
    public String createDateTimeStart;

    @Transient
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @ApiParam(value="创建日期查询用，查询结束日期",example = "2018-12-31 23:59:59")
    public String createDateTimeEnd;

    @Transient
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @ApiParam(value="修改日期查询用，查询起始日期",example = "2018-01-01 01:00:00")
    public String modifyDateTimeStart;

    @Transient
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @ApiParam(value = "修改日期查询用，查询结束日期",example = "2018-12-31 23:59:59")
    public String modifyDateTimeEnd;

    @Transient
    @ApiParam(value = "排序属性")
    public String orderByParam = "";

    @Transient
    @ApiParam(value = "排序类型，1 正序，2 倒序",example = "1")
    //CommonEnumUtil.ASC_OR_DESC  1 asc,2 desc
    public Integer ascOrDesc = 1;

    //排序方式
    public String orderBy(){
        String result = "";
        if (orderByParam!=null&&orderByParam.trim().length()>0) {
            result = " order by " + orderByParam;
            if(ascOrDesc == CommonEnumUtil.ASC_OR_DESC.ASC.getValue()) {
                result += " asc";
            }else{
                result += " desc";
            }
        }
        return result;
    }

}
